@@ -99,7 +99,7 @@ class Command(metaclass=abc.ABCMeta):
             rich.progress.SpinnerColumn(finished_text="[green]:heavy_check_mark:[/]"),
             "[progress.description]{task.description}",
             rich.progress.BarColumn(bar_width=60),
-            "[progress.completed]{task.completed}/{task.total}",
+            "[progress.completed]{task.completed:{task.fields[precision]}}/{task.total:{task.fields[precision]}}",
             "[progress.completed]{task.fields[unit]}",
             "[progress.percentage]{task.percentage:>3.0f}%",
             rich.progress.TimeElapsedColumn(),
@@ -124,9 +124,12 @@ class Command(metaclass=abc.ABCMeta):
         check: Optional[Callable[[_T], bool]] = None,
         message: Optional[str] = None,
         hint: Optional[str] = None,
+        optional: bool = False,
     ) -> _T:
         _convert = (lambda x: x) if convert is None else convert
         _check = (lambda x: True) if check is None else check
+        if optional and self.args[name] is None:
+            return None
         try:
             value = _convert(self.args[name])
             if not _check(value):
