@@ -44,7 +44,7 @@ class Annotate(Command):  # noqa: D101
                                           one of the sequences format supported
                                           by Biopython.
 
-        Parameters:
+        Parameters - Output:
             -f <fmt>, --format <fmt>      the format of the input file, as a
                                           Biopython format string. GECCO is able
                                           to recognize FASTA and GenBank files
@@ -55,9 +55,16 @@ class Annotate(Command):  # noqa: D101
                                           multithreading. Use 0 to use all of the
                                           available CPUs. [default: 0]
 
+        Parameters - Gene Calling:
+            -M, --mask                    Enable unknown region masking to
+                                          prevent genes from stretching across
+                                          unknown nucleotides.
+
         Parameters - Domain Annotation:
             -e <e>, --e-filter <e>        the e-value cutoff for protein domains
-                                          to be included.
+                                          to be included. This is not stable
+                                          across versions, so consider using
+                                          a p-value filter instead.
             -p <p>, --p-filter <p>        the p-value cutoff for protein domains
                                           to be included. [default: 1e-9]
 
@@ -88,6 +95,7 @@ class Annotate(Command):  # noqa: D101
             self.genome = self._check_flag("--genome")
             self.hmm = self._check_flag("--hmm")
             self.output = self._check_flag("--output")
+            self.mask = self._check_flag("--mask", bool)
         except InvalidArgument:
             raise CommandExit(1)
 
@@ -148,10 +156,10 @@ class Annotate(Command):  # noqa: D101
         from ...orf import PyrodigalFinder
 
         self.info("Extracting", "genes from input sequences", level=1)
-        orf_finder = PyrodigalFinder(metagenome=True, cpus=self.jobs)
+        orf_finder = PyrodigalFinder(metagenome=True, mask=self.mask, cpus=self.jobs)
 
         unit = "contigs" if len(sequences) > 1 else "contig"
-        task = self.progress.add_task(description="ORFs finding", total=len(sequences), unit=unit, precision="")
+        task = self.progress.add_task(description="Finding ORFs", total=len(sequences), unit=unit, precision="")
 
         def callback(record, found, total):
             self.success("Found", found, "genes in record", repr(record.id), level=2)
@@ -166,12 +174,12 @@ class Annotate(Command):  # noqa: D101
 
         # Run all HMMs over ORFs to annotate with protein domains
         hmms = list(self._custom_hmms() if self.hmm else embedded_hmms())
-        task = self.progress.add_task(description=f"HMM annotation", unit="HMMs", total=len(hmms), precision="")
+        task = self.progress.add_task(description=f"Annotating domains", unit="HMMs", total=len(hmms), precision="")
         for hmm in self.progress.track(hmms, task_id=task, total=len(hmms)):
-            task = self.progress.add_task(description=f"{hmm.id} v{hmm.version}", total=hmm.size, unit="domains", precision="")
+            task = self.progress.add_task(description=f"  {hmm.id} v{hmm.version}", total=hmm.size, unit="domains", precision="")
             callback = lambda h, t: self.progress.update(task, advance=1)
             self.info("Starting", f"annotation with [bold blue]{hmm.id} v{hmm.version}[/]", level=2)
-            features = PyHMMER(hmm, self.jobs, whitelist).run(genes, progress=callback)
+            PyHMMER(hmm, self.jobs, whitelist).run(genes, progress=callback)
             self.success("Finished", f"annotation with [bold blue]{hmm.id} v{hmm.version}[/]", level=2)
             self.progress.update(task_id=task, visible=False)
 
@@ -195,13 +203,17 @@ class Annotate(Command):  # noqa: D101
         if self.e_filter is not None:
             self.info("Filtering", "domains with e-value under", self.e_filter, level=1)
             key = lambda d: d.i_evalue < self.e_filter
-            for gene in genes:
-                gene.protein.domains = list(filter(key, gene.protein.domains))
+            genes = [
+                gene.with_protein(gene.protein.with_domains(filter(key, gene.protein.domains)))
+                for gene in genes
+            ]
         if self.p_filter is not None:
             self.info("Filtering", "domains with p-value under", self.p_filter, level=1)
             key = lambda d: d.pvalue < self.p_filter
-            for gene in genes:
-                gene.protein.domains = list(filter(key, gene.protein.domains))
+            genes = [
+                gene.with_protein(gene.protein.with_domains(filter(key, gene.protein.domains)))
+                for gene in genes
+            ]
         if self.p_filter is not None or self.e_filter is not None:
             count = sum(1 for gene in genes for domain in gene.protein.domains)
             self.info("Using", "remaining", count, "domains", level=1)
