@@ -130,7 +130,7 @@ class Domain:
         """
         return Domain(
             self.name, self.start, self.end, self.hmm, self.i_evalue, self.pvalue,
-            probability, self.qualifiers
+            probability, self.qualifiers.copy()
         )
 
     def to_seq_feature(self, protein_coordinates: bool = False) -> SeqFeature:
@@ -149,7 +149,7 @@ class Domain:
         return SeqFeature(location=loc, type="misc_feature", qualifiers=qualifiers)
 
 
-@dataclass
+@dataclass(frozen=True)
 class Protein:
     """A sequence of amino-acids translated from a gene.
 
@@ -179,8 +179,13 @@ class Protein:
 
         return record
 
+    def with_domains(self, domains: Iterable[Domain]) -> "Protein":
+        """Copy the current protein and assign it new domains.
+        """
+        return Protein(self.id, self.seq, list(domains))
 
-@dataclass
+
+@dataclass(frozen=True)
 class Gene:
     """A nucleotide sequence coding a protein.
 
@@ -240,6 +245,22 @@ class Gene:
         qualifiers.setdefault("translation", str(self.protein.seq))
         return SeqFeature(location=loc, type="CDS", qualifiers=qualifiers)
 
+    def with_protein(self, protein: "Protein") -> "Gene":
+        """Copy the current gene and assign it a different protein.
+        """
+        return Gene(
+            self.source, self.start, self.end, self.strand, protein,
+            self.qualifiers.copy(),
+        )
+
+    def with_source(self, source: "SeqRecord") -> "Gene":
+        """Copy the current gene and assign it a different source.
+        """
+        return Gene(
+            source, self.start, self.end, self.strand, self.protein,
+            self.qualifiers.copy(),
+        )
+
 
 @dataclass
 class Cluster:
@@ -414,7 +435,7 @@ class Cluster:
         structured_comment['GECCO-Data'] = {
             "version": f"GECCO v{__version__}",
             "creation_date": now.isoformat(),
-            "biosyn_class": ";".join(sorted(ty.name for ty in self.type.unpack())),
+            "biosyn_class": ";".join(sorted(ty.name for ty in self.type.unpack())) or "Unknown",
             "alkaloid_probability": self.type_probabilities.get(ProductType.Alkaloid, 0.0),
             "polyketide_probability": self.type_probabilities.get(ProductType.Polyketide, 0.0),
             "ripp_probability": self.type_probabilities.get(ProductType.RiPP, 0.0),
